@@ -1,4 +1,4 @@
-/* $Id: xfce-mcs-manager.c,v 1.32 2004/09/23 17:30:35 jasper Exp $ */
+/* $Id: xfce-mcs-manager.c,v 1.33 2004/11/03 10:18:55 jasper Exp $ */
 /*-
  * Copyright (c) 2002-2004 Olivier Fourdan <fourdan@xfce.org>
  * Copyright (c) 2003-2004 Benedikt Meurer <benny@xfce.org>
@@ -194,15 +194,39 @@ plugins_load_dir (const gchar *dir)
 static void
 plugin_load_all (void)
 {
+#ifdef DEBUG
+    g_message ("Loading mcs plugins");
+#endif
+
     /* load system plugins */
     plugins_load_dir (PLUGINSDIR);
 }
 
+static void
+unload_plugins (void)
+{
+#ifdef DEBUG
+    g_message ("Unloading mcs plugins");
+#endif
+
+    /*
+     * NOTE: Grabbing the X-Server while reloading the
+     * plugins will not work (Don't know why)
+     */
+    g_slist_foreach(module_list, (GFunc)g_module_close, NULL);
+    g_slist_free(module_list);
+    module_list = NULL;
+
+    g_slist_foreach(plugin_list, (GFunc)g_free, NULL);
+    g_slist_free(plugin_list);
+    plugin_list = NULL;
+}
+
 static void
 terminate_cb (void *data)
 {
 #ifdef DEBUG
-    g_print("Releasing the selection and exiting");
+    g_print("Releasing the selection and exitingn");
 #endif
 
     *(gboolean *)data = TRUE;
@@ -266,17 +290,7 @@ check_signal_state(void)
   {
 		sigstate = NOSIGNAL;
 
-		/*
-		 * NOTE: Grabbing the X-Server while reloading the
-		 * plugins will not work (Don't know why)
-		 */
-		g_slist_foreach(module_list, (GFunc)g_module_close, NULL);
-		g_slist_free(module_list);
-		module_list = NULL;
-
-		g_slist_foreach(plugin_list, (GFunc)g_free, NULL);
-		g_slist_free(plugin_list);
-		plugin_list = NULL;
+    unload_plugins();
 
 		plugin_load_all();
 	}
@@ -354,9 +368,13 @@ main (int argc, char **argv)
 #else
 	act.sa_flags = 0;
 #endif
+	sigaction (SIGTERM, &act, NULL);
+	sigaction (SIGHUP, &act, NULL);
 	sigaction (SIGINT, &act, NULL);
 	sigaction (SIGUSR1, &act, NULL);
 #else /* !HAVE_SIGACTION */
+	signal (SIGTERM, sighandler);
+	signal (SIGHUP, sighandler);
 	signal (SIGINT, sighandler);
 	signal (SIGUSR1, sighandler);
 #endif
@@ -390,13 +408,17 @@ main (int argc, char **argv)
 			_exit(EXIT_SUCCESS);
 	    	}
 #endif /* !HAVE_DAEMON */
-		/* Establish signal-check timer */
-		g_timeout_add(500, (GSourceFunc)check_signal_state, NULL);
 	}
 	else
 	    	g_message ("Daemon mode disabled (for debug purpose only!)");
 
+        /* Establish signal-check timer */
+        g_timeout_add(500, (GSourceFunc)check_signal_state, NULL);
+
 	gtk_main ();
+
+        unload_plugins ();
+  
 	mcs_manager_destroy (manager);
 
 	return EXIT_SUCCESS;
